@@ -48,7 +48,11 @@ class SearchWindow(QMainWindow, Ui_SearchWindow):
         super(SearchWindow, self).__init__(parent)
         self.setupUi(self)
         self.resultsWindow = ResultsWindow(self)
-        pixmap = QPixmap('/opt/RadiotimeToGo/radiotime_logo_400.png')
+        if os.path.isfile('/opt/RadiotimeToGo/radiotime_logo_400.png'):
+            pixmap = QPixmap('/opt/RadiotimeToGo/radiotime_logo_400.png')
+        else:
+            pixmap = QPixmap('radiotime_logo_400.png')
+
         self.results = []
         self.textLabelLogo.setPixmap(pixmap)
 
@@ -105,9 +109,14 @@ class ResultsWindow(QMainWindow, Ui_ResultsWindow):
                 populate_results(url, ui.results, self, True)
                 self.updatePushButton(0)
             else:
-                # os.system("/Applications/VLC.app/Contents/MacOS/VLC %s &" % ui.results[self.index].get('URL'))
-                os.system("/opt/kmplayer/bin/kmplayer %s &" % ui.results[self.index].get('URL'))
-    
+                if os.path.isfile('/opt/kmplayer/bin/kmplayer'):
+                    os.system('/opt/kmplayer/bin/kmplayer %s &' % ui.results[self.index].get('URL'))
+                elif os.path.isfile('/Applications/VLC.app/Contents/MacOS/VLC'):
+                    os.system('/Applications/VLC.app/Contents/MacOS/VLC %s &' % ui.results[self.index].get('URL'))
+                elif os.path.isfile('c:/program files/VideoLAN/vlc/vlc.exe'):
+                    os.system('"c:/program files/VideoLAN/vlc/vlc.exe" %s' % ui.results[self.index].get('URL'))
+
+
     def on_pushButtonBack_pressed(self):
         self.history.pop()
         ui.results = []
